"""
Integrated channel package for Enterprises.

Integrated channels are external systems that manage Enterprise Customer data. This package contains logic
for configuring integrated channels and sending data between us and an integrated channel.
"""
